# Generated by roxygen2: do not edit by hand

export(App)
export(async)
export(build_app)
export(rdesk_async)
export(rdesk_auto_update)
export(rdesk_cancel_job)
export(rdesk_create_app)
export(rdesk_df_to_list)
export(rdesk_error_plot)
export(rdesk_is_bundle)
export(rdesk_jobs_list)
export(rdesk_jobs_pending)
export(rdesk_message)
export(rdesk_parse_message)
export(rdesk_plot_to_base64)
export(rdesk_service)
importFrom(R6,R6Class)
importFrom(base64enc,base64encode)
importFrom(callr,r_bg)
importFrom(digest,digest)
importFrom(stats,runif)
