% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{rdesk_resolve_www}
\alias{rdesk_resolve_www}
\title{Resolve the www directory for an app}
\usage{
rdesk_resolve_www(www_dir)
}
\arguments{
\item{www_dir}{User-provided path to www directory (character)
Passing an explicit absolute path is the most reliable option and skips
the best-effort call-stack search.}
}
\value{
Normalized absolute path to a valid www directory
}
\description{
Resolve the www directory for an app
}
\keyword{internal}
