% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/async.R
\name{rdesk_stop_daemons}
\alias{rdesk_stop_daemons}
\title{Stop the mirai daemon pool}
\usage{
rdesk_stop_daemons()
}
\description{
Called at App$cleanup().
}
\keyword{internal}
