% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/window.R
\name{rdesk_read_events}
\alias{rdesk_read_events}
\title{Read all pending stdout lines from the launcher without blocking}
\usage{
rdesk_read_events(proc)
}
\arguments{
\item{proc}{Process object}
}
\value{
A list of parsed JSON events
}
\description{
Read all pending stdout lines from the launcher without blocking
}
\keyword{internal}
