% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{rdesk_df_to_list}
\alias{rdesk_df_to_list}
\title{Convert a data frame to a list suitable for JSON serialization}
\usage{
rdesk_df_to_list(df)
}
\arguments{
\item{df}{Data frame to convert}
}
\value{
A list with 'rows' (list of lists) and 'cols' (character vector)
}
\description{
Convert a data frame to a list suitable for JSON serialization
}
